@@ -38,6 +38,8 @@ sAppend(&sbOut, "#define gammaqInva _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rxnorm _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rxnormV _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rxbinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxnbinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rxnbinomMu _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rxcauchy _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rxchisq _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rxexp _rx%s%s%ld\n", extra, md5, __timeId++);
@@ -52,6 +54,8 @@ sAppend(&sbOut, "#define rxweibull _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rinorm _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rinormV _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define ribinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rinbinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define rinbinomMu _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define ricauchy _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define richisq _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define riexp _rx%s%s%ld\n", extra, md5, __timeId++);
@@ -63,6 +67,45 @@ sAppend(&sbOut, "#define ripois _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define rit_ _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define riunif _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define riweibull _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNorm _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNormDmean _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNormDsd _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikPois _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikPoisDlambda _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikBinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikBinomDprob _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNbinom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNbinomDprob _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNbinomMu _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikNbinomMuDmu _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikBeta _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikBetaDshape1 _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikBetaDshape2 _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikT _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikTDdf _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikTDmean _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikTDsd _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikChisq _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikChisqDdf _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikExp _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikExpDrate _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikF _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikFDdf1 _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikFDdf2 _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikGeom _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikGeomDp _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikUnif _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikUnifDalpha _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikUnifDbeta _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikWeibull _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikWeibullDshape _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikWeibullDscale _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikGamma _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikGammaDshape _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikGammaDrate _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikCauchy _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikCauchyDlocation _rx%s%s%ld\n", extra, md5, __timeId++);
+sAppend(&sbOut, "#define _llikCauchyDscale _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define _compareFactorVal _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define _sum _rx%s%s%ld\n", extra, md5, __timeId++);
 sAppend(&sbOut, "#define _sign _rx%s%s%ld\n", extra, md5, __timeId++);
@@ -112,6 +155,8 @@ sAppendN(&sbOut, "rxode2_fn2 gammaqInva;\n", 23);
 sAppendN(&sbOut, "rxode2i_fn2 rxnorm;\n", 20);
 sAppendN(&sbOut, "rxode2i_fn2 rxnormV;\n", 21);
 sAppendN(&sbOut, "rxode2i_rxbinom rxbinom;\n", 25);
+sAppendN(&sbOut, "rxode2i_rxbinom rxnbinom;\n", 26);
+sAppendN(&sbOut, "rxode2i_rxbinom rxnbinomMu;\n", 28);
 sAppendN(&sbOut, "rxode2i_fn2 rxcauchy;\n", 22);
 sAppendN(&sbOut, "rxode2i_fn rxchisq;\n", 20);
 sAppendN(&sbOut, "rxode2i_fn rxexp;\n", 18);
@@ -126,6 +171,8 @@ sAppendN(&sbOut, "rxode2i_fn2 rxweibull;\n", 23);
 sAppendN(&sbOut, "rxode2i2_fn2 rinorm;\n", 21);
 sAppendN(&sbOut, "rxode2i2_fn2 rinormV;\n", 22);
 sAppendN(&sbOut, "rxode2i2_ribinom ribinom;\n", 26);
+sAppendN(&sbOut, "rxode2i2_ribinom rinbinom;\n", 27);
+sAppendN(&sbOut, "rxode2i2_ribinom rinbinomMu;\n", 29);
 sAppendN(&sbOut, "rxode2i2_fn2 ricauchy;\n", 23);
 sAppendN(&sbOut, "rxode2i2_fn richisq;\n", 21);
 sAppendN(&sbOut, "rxode2i2_fn riexp;\n", 19);
@@ -137,6 +184,45 @@ sAppendN(&sbOut, "rxode2i2_ifn ripois;\n", 21);
 sAppendN(&sbOut, "rxode2i2_fn rit_;\n", 18);
 sAppendN(&sbOut, "rxode2i2_fn2 riunif;\n", 21);
 sAppendN(&sbOut, "rxode2i2_fn2 riweibull;\n", 24);
+sAppendN(&sbOut, "rxode2_llikNormFun _llikNorm;\n", 30);
+sAppendN(&sbOut, "rxode2_llikNormFun _llikNormDmean;\n", 35);
+sAppendN(&sbOut, "rxode2_llikNormFun _llikNormDsd;\n", 33);
+sAppendN(&sbOut, "rxode2_llikPoisFun _llikPois;\n", 30);
+sAppendN(&sbOut, "rxode2_llikPoisFun _llikPoisDlambda;\n", 37);
+sAppendN(&sbOut, "rxode2_llikBinomFun _llikBinom;\n", 32);
+sAppendN(&sbOut, "rxode2_llikBinomFun _llikBinomDprob;\n", 37);
+sAppendN(&sbOut, "rxode2_llikBinomFun _llikNbinom;\n", 33);
+sAppendN(&sbOut, "rxode2_llikBinomFun _llikNbinomDprob;\n", 38);
+sAppendN(&sbOut, "rxode2_llikBinomFun _llikNbinomMu;\n", 35);
+sAppendN(&sbOut, "rxode2_llikBinomFun _llikNbinomMuDmu;\n", 38);
+sAppendN(&sbOut, "rxode2_llikBetaFun _llikBeta;\n", 30);
+sAppendN(&sbOut, "rxode2_llikBetaFun _llikBetaDshape1;\n", 37);
+sAppendN(&sbOut, "rxode2_llikBetaFun _llikBetaDshape2;\n", 37);
+sAppendN(&sbOut, "rxode2_llikTFun _llikT;\n", 24);
+sAppendN(&sbOut, "rxode2_llikTFun _llikTDdf;\n", 27);
+sAppendN(&sbOut, "rxode2_llikTFun _llikTDmean;\n", 29);
+sAppendN(&sbOut, "rxode2_llikTFun _llikTDsd;\n", 27);
+sAppendN(&sbOut, "rxode2_llikChisqFun _llikChisq;\n", 32);
+sAppendN(&sbOut, "rxode2_llikChisqFun _llikChisqDdf;\n", 35);
+sAppendN(&sbOut, "rxode2_llikExpFun _llikExp;\n", 28);
+sAppendN(&sbOut, "rxode2_llikExpFun _llikExpDrate;\n", 33);
+sAppendN(&sbOut, "rxode2_llikFFun _llikF;\n", 24);
+sAppendN(&sbOut, "rxode2_llikFFun _llikFDdf1;\n", 28);
+sAppendN(&sbOut, "rxode2_llikFFun _llikFDdf2;\n", 28);
+sAppendN(&sbOut, "rxode2_llikGeomFun _llikGeom;\n", 30);
+sAppendN(&sbOut, "rxode2_llikGeomFun _llikGeomDp;\n", 32);
+sAppendN(&sbOut, "rxode2_llikUnifFun _llikUnif;\n", 30);
+sAppendN(&sbOut, "rxode2_llikUnifFun _llikUnifDalpha;\n", 36);
+sAppendN(&sbOut, "rxode2_llikUnifFun _llikUnifDbeta;\n", 35);
+sAppendN(&sbOut, "rxode2_llikWeibullFun _llikWeibull;\n", 36);
+sAppendN(&sbOut, "rxode2_llikWeibullFun _llikWeibullDshape;\n", 42);
+sAppendN(&sbOut, "rxode2_llikWeibullFun _llikWeibullDscale;\n", 42);
+sAppendN(&sbOut, "rxode2_llikGammaFun _llikGamma;\n", 32);
+sAppendN(&sbOut, "rxode2_llikGammaFun _llikGammaDshape;\n", 38);
+sAppendN(&sbOut, "rxode2_llikGammaFun _llikGammaDrate;\n", 37);
+sAppendN(&sbOut, "rxode2_llikCauchyFun _llikCauchy;\n", 34);
+sAppendN(&sbOut, "rxode2_llikCauchyFun _llikCauchyDlocation;\n", 43);
+sAppendN(&sbOut, "rxode2_llikCauchyFun _llikCauchyDscale;\n", 40);
 sAppendN(&sbOut, "rxode2_compareFactorVal_fn _compareFactorVal;\n", 46);
 sAppendN(&sbOut, "double _prod(double *input, double *p, int type, int n, ...){\n", 62);
 sAppendN(&sbOut, "  va_list valist;\n", 18);
@@ -176,21 +262,26 @@ sAppendN(&sbOut, "  va_end(valist);\n", 18);
 sAppendN(&sbOut, "  return s;\n", 12);
 sAppendN(&sbOut, "}\n", 2);
 sAppendN(&sbOut, "double _rxord(int _cSub, unsigned int n,  ...) {\n", 49);
+sAppendN(&sbOut, "  rx_solving_options_ind* ind = &(_solveData->subjects[_cSub]);\n", 64);
+sAppendN(&sbOut, "  if (!ind->inLhs) {\n", 21);
+sAppendN(&sbOut, "    return 1.0;\n", 16);
+sAppendN(&sbOut, "  }\n", 4);
 sAppendN(&sbOut, "  va_list valist;\n", 18);
 sAppendN(&sbOut, "  va_start(valist, n);\n", 23);
-sAppendN(&sbOut, "  double ret = 0.0;\n", 20);
+sAppendN(&sbOut, "  double ret = 1.0;\n", 20);
 sAppendN(&sbOut, "  double p = 0.0;\n", 18);
-sAppendN(&sbOut, "  double u = rxunif(&_solveData->subjects[_cSub], 0.0, 1.0);\n", 61);
+sAppendN(&sbOut, "  double u = rxunif(ind, 0.0, 1.0);\n", 36);
+sAppendN(&sbOut, "  int found = 0;\n", 17);
 sAppendN(&sbOut, "  for (unsigned int i = 0; i < n; i++) {\n", 41);
 sAppendN(&sbOut, "    p += va_arg(valist, double);\n", 33);
-sAppendN(&sbOut, "    if (ret < 1e-6) {\n", 22);
+sAppendN(&sbOut, "    if (!found) {\n", 18);
 sAppendN(&sbOut, "      if (u < p) {\n", 19);
 sAppendN(&sbOut, "        ret = (double)(i+1);\n", 29);
+sAppendN(&sbOut, "        found = 1;\n", 19);
 sAppendN(&sbOut, "      }\n", 8);
 sAppendN(&sbOut, "    }\n", 6);
 sAppendN(&sbOut, "  }\n", 4);
-sAppendN(&sbOut, "  if (p >= 1) ret = NA_REAL;\n", 29);
-sAppendN(&sbOut, "  else if (ret < 1e-6) ret = (double)(n+1);\n", 44);
+sAppendN(&sbOut, "  if (!found) ret =(double)(n+1);\n", 34);
 sAppendN(&sbOut, "  va_end(valist);\n", 18);
 sAppendN(&sbOut, "  return ret;\n", 14);
 sAppendN(&sbOut, "}\n", 2);
@@ -262,7 +353,9 @@ sAppendN(&sbOut, "  linCmtC=(linCmtA_p)R_GetCCallable(\"rxode2\", \"linCmtC\");\
 sAppendN(&sbOut, "    \n", 5);
 sAppendN(&sbOut, "  rxnorm = (rxode2i_fn2)R_GetCCallable(\"rxode2\", \"rxnorm\");\n", 60);
 sAppendN(&sbOut, "  rxnormV = (rxode2i_fn2)R_GetCCallable(\"rxode2\", \"rxnormV\");\n", 62);
-sAppendN(&sbOut, "  rxbinom = (rxode2i_rxbinom)R_GetCCallable(\"rxode2\",\"rxbinom\") ;\n", 66);
+sAppendN(&sbOut, "  rxbinom = (rxode2i_rxbinom)R_GetCCallable(\"rxode2\",\"rxbinom\");\n", 65);
+sAppendN(&sbOut, "  rxnbinom = (rxode2i_rxbinom)R_GetCCallable(\"rxode2\",\"rxnbinom\");\n", 67);
+sAppendN(&sbOut, "  rxnbinomMu = (rxode2i_rxbinom)R_GetCCallable(\"rxode2\",\"rxnbinomMu\");\n", 71);
 sAppendN(&sbOut, "  rxcauchy = (rxode2i_fn2)R_GetCCallable(\"rxode2\",\"rxcauchy\") ;\n", 64);
 sAppendN(&sbOut, "  rxchisq = (rxode2i_fn)R_GetCCallable(\"rxode2\",\"rxchisq\") ;\n", 61);
 sAppendN(&sbOut, "  rxexp = (rxode2i_fn)R_GetCCallable(\"rxode2\",\"rxexp\");\n", 56);
@@ -276,7 +369,9 @@ sAppendN(&sbOut, "  rxunif = (rxode2i_fn2)R_GetCCallable(\"rxode2\",\"rxunif\")
 sAppendN(&sbOut, "  rxweibull = (rxode2i_fn2)R_GetCCallable(\"rxode2\",\"rxweibull\");\n", 65);
 sAppendN(&sbOut, "  rinorm = (rxode2i2_fn2)R_GetCCallable(\"rxode2\", \"rinorm\");\n", 61);
 sAppendN(&sbOut, "  rinormV = (rxode2i2_fn2)R_GetCCallable(\"rxode2\", \"rinormV\");\n", 63);
-sAppendN(&sbOut, "  ribinom = (rxode2i2_ribinom)R_GetCCallable(\"rxode2\",\"ribinom\") ;\n", 67);
+sAppendN(&sbOut, "  ribinom = (rxode2i2_ribinom)R_GetCCallable(\"rxode2\",\"ribinom\");\n", 66);
+sAppendN(&sbOut, "  rinbinom = (rxode2i2_ribinom)R_GetCCallable(\"rxode2\",\"rinbinom\");\n", 68);
+sAppendN(&sbOut, "  rinbinomMu = (rxode2i2_ribinom)R_GetCCallable(\"rxode2\",\"rinbinomMu\");\n", 72);
 sAppendN(&sbOut, "  ricauchy = (rxode2i2_fn2)R_GetCCallable(\"rxode2\",\"ricauchy\") ;\n", 65);
 sAppendN(&sbOut, "  richisq = (rxode2i2_fn)R_GetCCallable(\"rxode2\",\"richisq\") ;\n", 62);
 sAppendN(&sbOut, "  riexp = (rxode2i2_fn)R_GetCCallable(\"rxode2\",\"riexp\");\n", 57);
@@ -306,6 +401,48 @@ sAppendN(&sbOut, "  simeps =(_simfun) R_GetCCallable(\"rxode2\", \"simeps\");\n"
 sAppendN(&sbOut, "  _compareFactorVal=(rxode2_compareFactorVal_fn) R_GetCCallable(\"rxode2\", \"compareFactorVal\");\n", 95);
 sAppendN(&sbOut, "  _update_par_ptr = (_update_par_ptr_p) R_GetCCallable(\"rxode2\",\"_update_par_ptr\");\n", 84);
 sAppendN(&sbOut, "  _getParCov = (_getParCov_p) R_GetCCallable(\"rxode2\",\"_getParCov\");\n", 69);
+sAppendN(&sbOut, "  \n", 3);
+sAppendN(&sbOut, "  _llikNorm=(rxode2_llikNormFun) R_GetCCallable(\"rxode2\",\"rxLlikNorm\");\n", 72);
+sAppendN(&sbOut, "  _llikNormDmean=(rxode2_llikNormFun) R_GetCCallable(\"rxode2\",\"rxLlikNormDmean\");\n", 82);
+sAppendN(&sbOut, "  _llikNormDsd=(rxode2_llikNormFun) R_GetCCallable(\"rxode2\",\"rxLlikNormDsd\");\n", 78);
+sAppendN(&sbOut, "  \n", 3);
+sAppendN(&sbOut, "  _llikPois        = (rxode2_llikPoisFun) R_GetCCallable(\"rxode2\",\"rxLlikPois\");\n", 81);
+sAppendN(&sbOut, "  _llikPoisDlambda = (rxode2_llikPoisFun) R_GetCCallable(\"rxode2\",\"rxLlikPoisDlambda\");\n", 88);
+sAppendN(&sbOut, "  _llikBinom = (rxode2_llikBinomFun) R_GetCCallable(\"rxode2\", \"rxLlikBinom\");\n", 78);
+sAppendN(&sbOut, "  _llikBinomDprob = (rxode2_llikBinomFun) R_GetCCallable(\"rxode2\", \"rxLlikBinomDprob\");\n", 88);
+sAppendN(&sbOut, "  _llikNbinom = (rxode2_llikBinomFun) R_GetCCallable(\"rxode2\", \"rxLlikNbinom\");\n", 80);
+sAppendN(&sbOut, "  _llikNbinomDprob = (rxode2_llikBinomFun) R_GetCCallable(\"rxode2\", \"rxLlikNbinomDprob\");\n", 90);
+sAppendN(&sbOut, "  \n", 3);
+sAppendN(&sbOut, "  _llikNbinomMu = (rxode2_llikBinomFun) R_GetCCallable(\"rxode2\", \"rxLlikNbinomMu\");\n", 84);
+sAppendN(&sbOut, "  _llikNbinomMuDmu = (rxode2_llikBinomFun) R_GetCCallable(\"rxode2\", \"rxLlikNbinomMuDmu\");\n", 90);
+sAppendN(&sbOut, "  _llikBeta = (rxode2_llikBetaFun)   R_GetCCallable(\"rxode2\", \"rxLlikBeta\");\n", 77);
+sAppendN(&sbOut, "  _llikBetaDshape1 = (rxode2_llikBetaFun) R_GetCCallable(\"rxode2\", \"rxLlikBetaDshape1\");\n", 89);
+sAppendN(&sbOut, "  _llikBetaDshape2 = (rxode2_llikBetaFun) R_GetCCallable(\"rxode2\", \"rxLlikBetaDshape2\");\n", 89);
+sAppendN(&sbOut, "  _llikT = (rxode2_llikTFun)   R_GetCCallable(\"rxode2\", \"rxLlikT\");\n", 68);
+sAppendN(&sbOut, "  _llikTDdf = (rxode2_llikTFun) R_GetCCallable(\"rxode2\", \"rxLlikTDdf\");\n", 72);
+sAppendN(&sbOut, "  _llikTDmean = (rxode2_llikTFun) R_GetCCallable(\"rxode2\", \"rxLlikTDmean\");\n", 76);
+sAppendN(&sbOut, "  _llikTDsd = (rxode2_llikTFun) R_GetCCallable(\"rxode2\", \"rxLlikTDsd\");\n", 72);
+sAppendN(&sbOut, "  _llikChisq    = (rxode2_llikChisqFun) R_GetCCallable(\"rxode2\", \"rxLlikChisq\");\n", 81);
+sAppendN(&sbOut, "  _llikChisqDdf = (rxode2_llikChisqFun) R_GetCCallable(\"rxode2\", \"rxLlikChisqDdf\");\n", 84);
+sAppendN(&sbOut, "  _llikExp    = (rxode2_llikExpFun) R_GetCCallable(\"rxode2\", \"rxLlikExp\");\n", 75);
+sAppendN(&sbOut, "  _llikExpDrate = (rxode2_llikExpFun) R_GetCCallable(\"rxode2\", \"rxLlikExpDrate\");\n", 82);
+sAppendN(&sbOut, "  _llikF    = (rxode2_llikFFun) R_GetCCallable(\"rxode2\", \"rxLlikF\");\n", 69);
+sAppendN(&sbOut, "  _llikFDdf1 = (rxode2_llikFFun) R_GetCCallable(\"rxode2\", \"rxLlikFDdf1\");\n", 74);
+sAppendN(&sbOut, "  _llikFDdf2 = (rxode2_llikFFun) R_GetCCallable(\"rxode2\", \"rxLlikFDdf2\");\n", 74);
+sAppendN(&sbOut, "  _llikGeom    = (rxode2_llikGeomFun) R_GetCCallable(\"rxode2\", \"rxLlikGeom\");\n", 78);
+sAppendN(&sbOut, "  _llikGeomDp  = (rxode2_llikGeomFun) R_GetCCallable(\"rxode2\", \"rxLlikGeomDp\");\n", 80);
+sAppendN(&sbOut, "  _llikUnif        = (rxode2_llikUnifFun) R_GetCCallable(\"rxode2\", \"rxLlikUnif\");\n", 82);
+sAppendN(&sbOut, "  _llikUnifDalpha  = (rxode2_llikUnifFun) R_GetCCallable(\"rxode2\", \"rxLlikUnifDalpha\");\n", 88);
+sAppendN(&sbOut, "  _llikUnifDbeta   = (rxode2_llikUnifFun) R_GetCCallable(\"rxode2\", \"rxLlikUnifDbeta\");\n", 87);
+sAppendN(&sbOut, "  _llikWeibull        = (rxode2_llikWeibullFun) R_GetCCallable(\"rxode2\", \"rxLlikWeibull\");\n", 91);
+sAppendN(&sbOut, "  _llikWeibullDshape  = (rxode2_llikWeibullFun) R_GetCCallable(\"rxode2\", \"rxLlikWeibullDshape\");\n", 97);
+sAppendN(&sbOut, "  _llikWeibullDscale   = (rxode2_llikWeibullFun) R_GetCCallable(\"rxode2\", \"rxLlikWeibullDscale\");\n", 98);
+sAppendN(&sbOut, "  _llikGamma        = (rxode2_llikGammaFun) R_GetCCallable(\"rxode2\", \"rxLlikGamma\");\n", 85);
+sAppendN(&sbOut, "  _llikGammaDshape  = (rxode2_llikGammaFun) R_GetCCallable(\"rxode2\", \"rxLlikGammaDshape\");\n", 91);
+sAppendN(&sbOut, "  _llikGammaDrate   = (rxode2_llikGammaFun) R_GetCCallable(\"rxode2\", \"rxLlikGammaDrate\");\n", 90);
+sAppendN(&sbOut, "  _llikCauchy        = (rxode2_llikCauchyFun) R_GetCCallable(\"rxode2\", \"rxLlikCauchy\");\n", 88);
+sAppendN(&sbOut, "  _llikCauchyDlocation  = (rxode2_llikCauchyFun) R_GetCCallable(\"rxode2\", \"rxLlikCauchyDlocation\");\n", 100);
+sAppendN(&sbOut, "  _llikCauchyDscale   = (rxode2_llikCauchyFun) R_GetCCallable(\"rxode2\", \"rxLlikCauchyDscale\");\n", 95);
 sAppendN(&sbOut, "  _solveData = _getRxSolve_();\n", 31);
 sAppendN(&sbOut, "}\n", 2);
 sAppendN(&sbOut, "void _assignFuns() {\n", 21);
@@ -351,6 +488,8 @@ sAppendN(&sbOut, "#undef gammaqInva\n", 18);
 sAppendN(&sbOut, "#undef rxnorm\n", 14);
 sAppendN(&sbOut, "#undef rxnormV\n", 15);
 sAppendN(&sbOut, "#undef rxbinom\n", 15);
+sAppendN(&sbOut, "#undef rxnbinom\n", 16);
+sAppendN(&sbOut, "#undef rxnbinomMu\n", 18);
 sAppendN(&sbOut, "#undef rxcauchy\n", 16);
 sAppendN(&sbOut, "#undef rxchisq\n", 15);
 sAppendN(&sbOut, "#undef rxexp\n", 13);
@@ -365,6 +504,8 @@ sAppendN(&sbOut, "#undef rxweibull\n", 17);
 sAppendN(&sbOut, "#undef rinorm\n", 14);
 sAppendN(&sbOut, "#undef rinormV\n", 15);
 sAppendN(&sbOut, "#undef ribinom\n", 15);
+sAppendN(&sbOut, "#undef rinbinom\n", 16);
+sAppendN(&sbOut, "#undef rinbinomMu\n", 18);
 sAppendN(&sbOut, "#undef ricauchy\n", 16);
 sAppendN(&sbOut, "#undef richisq\n", 15);
 sAppendN(&sbOut, "#undef riexp\n", 13);
@@ -376,6 +517,45 @@ sAppendN(&sbOut, "#undef ripois\n", 14);
 sAppendN(&sbOut, "#undef rit_\n", 12);
 sAppendN(&sbOut, "#undef riunif\n", 14);
 sAppendN(&sbOut, "#undef riweibull\n", 17);
+sAppendN(&sbOut, "#undef _llikNorm\n", 17);
+sAppendN(&sbOut, "#undef _llikNormDmean\n", 22);
+sAppendN(&sbOut, "#undef _llikNormDsd\n", 20);
+sAppendN(&sbOut, "#undef _llikPois\n", 17);
+sAppendN(&sbOut, "#undef _llikPoisDlambda\n", 24);
+sAppendN(&sbOut, "#undef _llikBinom\n", 18);
+sAppendN(&sbOut, "#undef _llikBinomDprob\n", 23);
+sAppendN(&sbOut, "#undef _llikNbinom\n", 19);
+sAppendN(&sbOut, "#undef _llikNbinomDprob\n", 24);
+sAppendN(&sbOut, "#undef _llikNbinomMu\n", 21);
+sAppendN(&sbOut, "#undef _llikNbinomMuDmu\n", 24);
+sAppendN(&sbOut, "#undef _llikBeta\n", 17);
+sAppendN(&sbOut, "#undef _llikBetaDshape1\n", 24);
+sAppendN(&sbOut, "#undef _llikBetaDshape2\n", 24);
+sAppendN(&sbOut, "#undef _llikT\n", 14);
+sAppendN(&sbOut, "#undef _llikTDdf\n", 17);
+sAppendN(&sbOut, "#undef _llikTDmean\n", 19);
+sAppendN(&sbOut, "#undef _llikTDsd\n", 17);
+sAppendN(&sbOut, "#undef _llikChisq\n", 18);
+sAppendN(&sbOut, "#undef _llikChisqDdf\n", 21);
+sAppendN(&sbOut, "#undef _llikExp\n", 16);
+sAppendN(&sbOut, "#undef _llikExpDrate\n", 21);
+sAppendN(&sbOut, "#undef _llikF\n", 14);
+sAppendN(&sbOut, "#undef _llikFDdf1\n", 18);
+sAppendN(&sbOut, "#undef _llikFDdf2\n", 18);
+sAppendN(&sbOut, "#undef _llikGeom\n", 17);
+sAppendN(&sbOut, "#undef _llikGeomDp\n", 19);
+sAppendN(&sbOut, "#undef _llikUnif\n", 17);
+sAppendN(&sbOut, "#undef _llikUnifDalpha\n", 23);
+sAppendN(&sbOut, "#undef _llikUnifDbeta\n", 22);
+sAppendN(&sbOut, "#undef _llikWeibull\n", 20);
+sAppendN(&sbOut, "#undef _llikWeibullDshape\n", 26);
+sAppendN(&sbOut, "#undef _llikWeibullDscale\n", 26);
+sAppendN(&sbOut, "#undef _llikGamma\n", 18);
+sAppendN(&sbOut, "#undef _llikGammaDshape\n", 24);
+sAppendN(&sbOut, "#undef _llikGammaDrate\n", 23);
+sAppendN(&sbOut, "#undef _llikCauchy\n", 19);
+sAppendN(&sbOut, "#undef _llikCauchyDlocation\n", 28);
+sAppendN(&sbOut, "#undef _llikCauchyDscale\n", 25);
 sAppendN(&sbOut, "#undef _compareFactorVal\n", 25);
 sAppendN(&sbOut, "#undef _sum\n", 12);
 sAppendN(&sbOut, "#undef _sign\n", 13);
