@@ -11,6 +11,7 @@
 #define __DOINIT__
 #include "tran.h"
 #include "rxthreefry.h"
+#include "llik.h"
 #include "cbindThetaOmega.h"
 #include "seed.h"
 #include "getTime.h"
@@ -101,6 +102,22 @@ SEXP _rxode2_nestingInfo_(SEXP omega, SEXP data);
 
 SEXP _rxode2_isNullZero(SEXP in);
 
+SEXP _rxode2_llikNormInternal(SEXP xSEXP, SEXP muSEXP, SEXP sigmaSEXP);
+SEXP _rxode2_llikPoisInternal(SEXP xSEXP, SEXP lambdaSEXP);
+SEXP _rxode2_llikBinomInternal(SEXP xSEXP, SEXP sizeSEXP, SEXP probSEXP);
+SEXP _rxode2_llikNbinomMuInternal(SEXP xSEXP, SEXP sizeSEXP, SEXP muSEXP);
+SEXP _rxode2_llikNbinomInternal(SEXP xSEXP, SEXP sizeSEXP, SEXP probSEXP);
+SEXP _rxode2_llikBetaInternal(SEXP xSEXP, SEXP shape1SEXP, SEXP shape2SEXP);
+SEXP _rxode2_llikTInternal(SEXP xSEXP, SEXP df1SEXP, SEXP meanSEXP, SEXP sdSEXP);
+SEXP _rxode2_llikChisqInternal(SEXP xSEXP, SEXP dfSEXP);
+SEXP _rxode2_llikExpInternal(SEXP xSEXP, SEXP rateSEXP);
+SEXP _rxode2_llikFInternal(SEXP xSEXP, SEXP df1SEXP, SEXP df2SEXP);
+SEXP _rxode2_llikGeomInternal(SEXP xSEXP, SEXP pSEXP);
+SEXP _rxode2_llikUnifInternal(SEXP xSEXP, SEXP alphaSEXP, SEXP betaSEXP);
+SEXP _rxode2_llikWeibullInternal(SEXP xSEXP, SEXP shapeSEXP, SEXP sizeSEXP);
+SEXP _rxode2_llikGammaInternal(SEXP xSEXP, SEXP shapeSEXP, SEXP rateSEXP);
+SEXP _rxode2_llikCauchyInternal(SEXP xSEXP, SEXP locationSEXP, SEXP scaleSEXP);
+
 SEXP rxode2_get_mv();
 SEXP _rxode2_rxGetSeed();
 
@@ -196,6 +213,8 @@ SEXP _rxode2_rxexp_(SEXP, SEXP, SEXP);
 SEXP _rxode2_rxchisq_(SEXP, SEXP, SEXP);
 SEXP _rxode2_rxcauchy_(SEXP, SEXP, SEXP, SEXP);
 SEXP _rxode2_rxbinom_(SEXP, SEXP, SEXP, SEXP);
+SEXP _rxode2_rxnbinomMu_(SEXP, SEXP, SEXP, SEXP);
+SEXP _rxode2_rxnbinom_(SEXP, SEXP, SEXP, SEXP);
 
 SEXP _rxode2_rxRmvn0(SEXP, SEXP, SEXP, SEXP, SEXP,
 		    SEXP, SEXP, SEXP, SEXP, SEXP,
@@ -322,7 +341,7 @@ void R_init_rxode2(DllInfo *info){
     {"_rxTick", (DL_FUNC) &_rxTick, 0},
     {"_rxProgressStop", (DL_FUNC) &_rxProgressStop, 1},
     {"_rxProgressAbort", (DL_FUNC) &_rxProgressAbort, 1},
-    {"_rxode2_trans", (DL_FUNC) &_rxode2_trans, 7},
+    {"_rxode2_trans", (DL_FUNC) &_rxode2_trans, 8},
     {"_rxode2_codegen", (DL_FUNC) &_rxode2_codegen, 6},
     {"_rxode2_codeLoaded", (DL_FUNC) &_rxode2_codeLoaded, 0},
     {"_rxode2_parseModel", (DL_FUNC) &_rxode2_parseModel, 1},
@@ -414,6 +433,8 @@ void R_init_rxode2(DllInfo *info){
     {"_rxode2_rxchisq_", (DL_FUNC) &_rxode2_rxchisq_, 3},
     {"_rxode2_rxcauchy_", (DL_FUNC) &_rxode2_rxcauchy_, 4},
     {"_rxode2_rxbinom_", (DL_FUNC) &_rxode2_rxbinom_, 4},
+    {"_rxode2_rxnbinomMu_", (DL_FUNC) &_rxode2_rxnbinomMu_, 4},
+    {"_rxode2_rxnbinom_", (DL_FUNC) &_rxode2_rxnbinomMu_, 4},
     {"_rxode2_rxSolveDollarNames", (DL_FUNC) _rxode2_rxSolveDollarNames, 1},
     {"_rxode2_etDollarNames", (DL_FUNC) _rxode2_etDollarNames, 1},
     {"_rxode2_rxExpandNesting", (DL_FUNC) _rxode2_rxExpandNesting, 3},
@@ -458,7 +479,22 @@ void R_init_rxode2(DllInfo *info){
     {"_rxSetSeed", (DL_FUNC) _rxSetSeed, 1},
     {"_rxode2_rxordSelect", (DL_FUNC) _rxode2_rxordSelect, 2},
     {"_rxode2_rxErf", (DL_FUNC) &_rxode2_rxErf, 1},
-    {NULL, NULL, 0}
+    {"_rxode2_llikNormInternal", (DL_FUNC) &_rxode2_llikNormInternal, 3},
+    {"_rxode2_llikPoisInternal", (DL_FUNC) &_rxode2_llikPoisInternal, 2},
+    {"_rxode2_llikBinomInternal",(DL_FUNC) &_rxode2_llikBinomInternal, 3},
+    {"_rxode2_llikNbinomMuInternal",(DL_FUNC) &_rxode2_llikNbinomMuInternal, 3},
+    {"_rxode2_llikNbinomInternal",(DL_FUNC) &_rxode2_llikNbinomInternal, 3},
+    {"_rxode2_llikBetaInternal", (DL_FUNC) &_rxode2_llikBetaInternal, 3},
+    {"_rxode2_llikTInternal", (DL_FUNC) &_rxode2_llikTInternal, 4},
+    {"_rxode2_llikChisqInternal", (DL_FUNC) &_rxode2_llikChisqInternal, 2},
+    {"_rxode2_llikExpInternal", (DL_FUNC) &_rxode2_llikExpInternal, 2},
+    {"_rxode2_llikFInternal", (DL_FUNC) &_rxode2_llikFInternal, 3},
+    {"_rxode2_llikGeomInternal", (DL_FUNC) &_rxode2_llikGeomInternal, 2},
+    {"_rxode2_llikUnifInternal", (DL_FUNC) &_rxode2_llikUnifInternal, 3},
+    {"_rxode2_llikWeibullInternal", (DL_FUNC) &_rxode2_llikWeibullInternal, 3},
+    {"_rxode2_llikGammaInternal", (DL_FUNC) &_rxode2_llikGammaInternal, 3},
+    {"_rxode2_llikCauchyInternal", (DL_FUNC) &_rxode2_llikCauchyInternal, 3},
+    {NULL, NULL, 0} 
   };
   // C callable to assign environments.
   R_RegisterCCallable("rxode2","_rxode2_rxQr", (DL_FUNC) &_rxode2_rxQr);
@@ -475,6 +511,8 @@ void R_init_rxode2(DllInfo *info){
   R_RegisterCCallable("rxode2", "rxgamma", (DL_FUNC) &rxgamma);
   R_RegisterCCallable("rxode2", "rxbeta", (DL_FUNC) &rxbeta);
   R_RegisterCCallable("rxode2", "rxbinom", (DL_FUNC) &rxbinom);
+  R_RegisterCCallable("rxode2", "rxnbinomMu", (DL_FUNC) &rxnbinomMu);
+  R_RegisterCCallable("rxode2", "rxnbinom", (DL_FUNC) &rxnbinom);
   R_RegisterCCallable("rxode2", "rxcauchy", (DL_FUNC) &rxcauchy);
   R_RegisterCCallable("rxode2", "rxchisq", (DL_FUNC) &rxchisq);
   R_RegisterCCallable("rxode2", "rxexp", (DL_FUNC) &rxexp);
@@ -489,6 +527,8 @@ void R_init_rxode2(DllInfo *info){
   R_RegisterCCallable("rxode2", "rigamma", (DL_FUNC) &rigamma);
   R_RegisterCCallable("rxode2", "ribeta", (DL_FUNC) &ribeta);
   R_RegisterCCallable("rxode2", "ribinom", (DL_FUNC) &ribinom);
+  R_RegisterCCallable("rxode2", "rinbinomMu", (DL_FUNC) &rinbinomMu);
+  R_RegisterCCallable("rxode2", "rinbinom", (DL_FUNC) &rinbinom);
   R_RegisterCCallable("rxode2", "ricauchy", (DL_FUNC) &ricauchy);
   R_RegisterCCallable("rxode2", "richisq", (DL_FUNC) &richisq);
   R_RegisterCCallable("rxode2", "riexp", (DL_FUNC) &riexp);
@@ -549,7 +589,49 @@ void R_init_rxode2(DllInfo *info){
   R_RegisterCCallable("rxode2", "handleTlast", (DL_FUNC) &handleTlast);
   R_RegisterCCallable("rxode2", "rxGetId", (DL_FUNC) &rxGetId);
   R_RegisterCCallable("rxode2", "getTime", (DL_FUNC) &getTime);
-  
+
+  // log likelihoods used in calculations
+  R_RegisterCCallable("rxode2", "rxLlikNorm", (DL_FUNC) &rxLlikNorm);
+  R_RegisterCCallable("rxode2", "rxLlikNormDmean", (DL_FUNC) &rxLlikNormDmean);
+  R_RegisterCCallable("rxode2", "rxLlikNormDsd", (DL_FUNC) &rxLlikNormDsd);
+  R_RegisterCCallable("rxode2", "rxLlikPois", (DL_FUNC) &rxLlikPois);
+  R_RegisterCCallable("rxode2", "rxLlikPoisDlambda", (DL_FUNC) &rxLlikPoisDlambda);
+  R_RegisterCCallable("rxode2", "rxLlikBinom", (DL_FUNC) &rxLlikBinom);
+  R_RegisterCCallable("rxode2", "rxLlikBinomDprob", (DL_FUNC) &rxLlikBinomDprob);
+  R_RegisterCCallable("rxode2", "rxLlikNbinomMu", (DL_FUNC) &rxLlikNbinomMu);
+  R_RegisterCCallable("rxode2", "rxLlikNbinomMuDmu", (DL_FUNC) &rxLlikNbinomMuDmu);
+  R_RegisterCCallable("rxode2", "rxLlikNbinom", (DL_FUNC) &rxLlikNbinom);
+  R_RegisterCCallable("rxode2", "rxLlikNbinomDprob", (DL_FUNC) &rxLlikNbinomDprob);
+
+  R_RegisterCCallable("rxode2", "rxLlikBeta", (DL_FUNC) &rxLlikBeta);
+  R_RegisterCCallable("rxode2", "rxLlikBetaDshape1", (DL_FUNC) &rxLlikBetaDshape1);
+  R_RegisterCCallable("rxode2", "rxLlikBetaDshape2", (DL_FUNC) &rxLlikBetaDshape2);
+  R_RegisterCCallable("rxode2", "rxLlikT", (DL_FUNC) &rxLlikT);
+  R_RegisterCCallable("rxode2", "rxLlikTDdf", (DL_FUNC) &rxLlikTDdf);
+  R_RegisterCCallable("rxode2", "rxLlikTDmean", (DL_FUNC) &rxLlikTDmean);
+  R_RegisterCCallable("rxode2", "rxLlikTDsd", (DL_FUNC) &rxLlikTDsd);
+  R_RegisterCCallable("rxode2", "rxLlikChisq", (DL_FUNC) &rxLlikChisq);
+  R_RegisterCCallable("rxode2", "rxLlikChisqDdf", (DL_FUNC) &rxLlikChisqDdf);
+  R_RegisterCCallable("rxode2", "rxLlikExp", (DL_FUNC) &rxLlikExp);
+  R_RegisterCCallable("rxode2", "rxLlikExpDrate", (DL_FUNC) &rxLlikExpDrate);
+  R_RegisterCCallable("rxode2", "rxLlikF", (DL_FUNC) &rxLlikF);
+  R_RegisterCCallable("rxode2", "rxLlikFDdf1", (DL_FUNC) &rxLlikFDdf1);
+  R_RegisterCCallable("rxode2", "rxLlikFDdf2", (DL_FUNC) &rxLlikFDdf2);
+  R_RegisterCCallable("rxode2", "rxLlikGeom", (DL_FUNC) &rxLlikGeom);
+  R_RegisterCCallable("rxode2", "rxLlikGeomDp", (DL_FUNC) &rxLlikGeomDp);
+  R_RegisterCCallable("rxode2", "rxLlikUnif", (DL_FUNC) &rxLlikUnif);
+  R_RegisterCCallable("rxode2", "rxLlikUnifDalpha", (DL_FUNC) &rxLlikUnifDalpha);
+  R_RegisterCCallable("rxode2", "rxLlikUnifDbeta", (DL_FUNC) &rxLlikUnifDbeta);
+  R_RegisterCCallable("rxode2", "rxLlikWeibull", (DL_FUNC) &rxLlikWeibull);
+  R_RegisterCCallable("rxode2", "rxLlikWeibullDshape", (DL_FUNC) &rxLlikWeibullDshape);
+  R_RegisterCCallable("rxode2", "rxLlikWeibullDscale", (DL_FUNC) &rxLlikWeibullDscale);
+  R_RegisterCCallable("rxode2", "rxLlikGamma", (DL_FUNC) &rxLlikGamma);
+  R_RegisterCCallable("rxode2", "rxLlikGammaDshape", (DL_FUNC) &rxLlikGammaDshape);
+  R_RegisterCCallable("rxode2", "rxLlikGammaDrate", (DL_FUNC) &rxLlikGammaDrate);
+  R_RegisterCCallable("rxode2", "rxLlikCauchy", (DL_FUNC) &rxLlikCauchy);
+  R_RegisterCCallable("rxode2", "rxLlikCauchyDlocation", (DL_FUNC) &rxLlikCauchyDlocation);
+  R_RegisterCCallable("rxode2", "rxLlikCauchyDscale", (DL_FUNC) &rxLlikCauchyDscale);
+
   static const R_CMethodDef cMethods[] = {
     {"rxode2_sum",               (DL_FUNC) &rxode2_sum, 2, rxode2_Sum_t},
     {"rxode2_prod",              (DL_FUNC) &rxode2_prod, 2, rxode2_Sum_t},
