@@ -1,4 +1,5 @@
 rxTest({
+
   warn1 <- function(code) {
     if (rxCores() == 1L) {
       x <- force(code)
@@ -9,6 +10,7 @@ rxTest({
   }
 
   test_that("rnorm", {
+
     rxWithSeed(1024, {
       rx <- rxode2({
         x1 <- rnorm()
@@ -19,7 +21,7 @@ rxTest({
 
       ev <- et(1, id = 1:70000)
 
-      f <- suppressMessages(warn1(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2))
 
       expect_equal(mean(f$x1), 0, tolerance = 1e-2)
       expect_equal(sd(f$x1), 1, tolerance = 1e-2)
@@ -116,7 +118,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       expect_equal(max(f$x1), 4)
       expect_equal(min(f$x1), 0)
@@ -173,7 +175,7 @@ rxTest({
 
       ev <- et(1, id = 1:100)
 
-      f <- suppressMessages(warn1(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2))
       ## Seed tests
 
       ## Make sure seeds are reproducible
@@ -208,7 +210,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       expect_equal(mean(f$x1), 15, tolerance = 0.1)
       expect_equal(sd(f$x1), sqrt(2 * 15), tolerance = 0.1)
@@ -255,7 +257,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       expect_equal(mean(f$x1), 2, tolerance = 0.1)
       expect_equal(sd(f$x1), sqrt(1 / (0.5 * 0.5)), tolerance = 0.1)
@@ -297,7 +299,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       sf <- function(d1, d2) {
         sqrt((2 * d2^2 * (d1 + d2 - 2)) / (d1 * (d2 - 2)^2 * (d2 - 4)))
@@ -355,7 +357,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       sgamma <- function(k, theta = 1) {
         sqrt(k / (theta^2))
@@ -403,7 +405,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
 
       mbeta <- function(a, b) {
@@ -462,7 +464,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       # expect_equal(median(f$x1), -ceiling(1 / log2(1 - 0.5)))
       expect_equal(median(f$x2), -ceiling(1 / log2(1 - 0.1)))
@@ -501,7 +503,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       expect_equal(mean(f$x1), 1, tolerance = 0.01)
       expect_equal(sd(f$x1), 1, tolerance = 0.01)
@@ -546,7 +548,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       expect_equal(mean(f$x1), 0, tolerance = 0.1)
       expect_equal(sd(f$x1), sqrt(15 / (15 - 2)), tolerance = 0.1)
@@ -595,7 +597,7 @@ rxTest({
 
       ev <- et(1, id = 1:30000)
 
-      f <- suppressMessages(warn1(rxSolve(rx, ev, c(a = 0.5, b = 0.25, c = 0.75), cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, c(a = 0.5, b = 0.25, c = 0.75), cores = 2))
 
       expect_equal(mean(f$x1), 0.5, tolerance = 1e-2)
       expect_equal(sd(f$x1), sqrt(1 / 12), tolerance = 1e-2)
@@ -649,7 +651,7 @@ rxTest({
     ev <- et(1, id = 1:30000)
 
     rxWithSeed(1024, {
-      f <- suppressMessages(warn1(rxSolve(rx, ev, cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, cores = 2))
 
       mweibull <- function(shape, scale = 1) {
         lambda <- scale
@@ -734,7 +736,7 @@ rxTest({
     rxWithSeed(10, {
       ev <- et(c(1, 2), id = 1:5)
 
-      f <- suppressMessages(warn1(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2))
 
       expect_equal(sum(duplicated(f$x0)), 0)
 
@@ -778,7 +780,7 @@ rxTest({
 
       ev <- et(c(1, 2), id = 1:5)
 
-      f <- suppressMessages(warn1(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2)))
+      f <- suppressMessages(rxSolve(rx, ev, c(a = 3, b = 5, c = 2), cores = 2))
 
       expect_equal(sum(duplicated(f$x0)), 0)
 
